'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function isPlainObject(value) {
	if (Object.prototype.toString.call(value) !== '[object Object]') {
		return false;
	}

	const prototype = Object.getPrototypeOf(value);
	return prototype === null || prototype === Object.prototype;
}

/* eslint-disable @typescript-eslint/no-unsafe-return, @typescript-eslint/no-unsafe-assignment */
/**
 * Turns the null values of an object into undefined
 */
function nullToUndefined(value) {
    if (typeof value !== 'object')
        return value; // typeof `null` is an object
    if (value === null)
        return undefined;
    if (Array.isArray(value)) {
        return value.map((item) => nullToUndefined(item));
    }
    if (!isPlainObject(value))
        return value;
    const newObj = {};
    for (const k of Object.keys(value)) {
        const v = value[k];
        newObj[k] = v === null ? undefined : nullToUndefined(v);
    }
    return newObj;
}

exports.nullToUndefined = nullToUndefined;
